description property
On iOS/macOS description will be either achievedDescription or
unachievedDescription, depending on whether or not the achievement has been unlocked.
Implementation
final String description;
On iOS/macOS description will be either achievedDescription or
unachievedDescription, depending on whether or not the achievement has been unlocked.
final String description;